Module ledger_runner

Module ledger_runner 

Runs Ledger-cli to retrieve required reports.

Functions

get_ledger_start_date
Determines the starting date from which to take Ledger transactions. This is one month from the comparison date.
get_ledger_tx
Get ledger transactions Ledger must be callable from the current directory.